
Insecure internal communication
-------

**Description:**

Whenever organisations communicate by means of unencrypted connections, an attacker 
could easily sniff these insecure communication and gain sensitive information.


**Solution:**

Use TLS encrypted data lines for all internal communication channels.
Also your infrastructure should not traverse unencrypted or weakly encrypted links. Because
if so, than al your data's integrity and confidentiality will be lost.



	
